@@ -1,32 +1,7 @@
-/*
- * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
- * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
- * NON-INFRINGEMENT.  See the GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
- *
- * In addition, as a special exception, the copyright holders give
- * permission to link the code of portions of this program with the
- * OpenSSL library under certain conditions as described in each
- * individual source file, and distribute linked combinations
- * including the two.
- * You must obey the GNU General Public License in all respects
- * for all of the code used other than OpenSSL.  If you modify
- * file(s) with this exception, you may extend this exception to your
- * version of the file(s), but you are not obligated to do so.  If you
- * do not wish to do so, delete this exception statement from your
- * version.  If you delete this exception statement from all source
- * files in the program, then also delete it here.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef _DMR_PLAYLIST_MODEL_H
 #define _DMR_PLAYLIST_MODEL_H
 
@@ -86,6 +61,23 @@ struct MovieInfo {
 #ifdef _MOVIE_USE_
     QString strFmtName; // 文件封装名
 #endif
+    MovieInfo() {
+        valid = false;
+        raw_rotate = -1;
+        fileSize = -1;
+        duration = -1;
+        width = -1;
+        height = -1;
+        vCodecID = -1;
+        aCodeRate = -1;
+        fps = -1;
+        proportion = -1.0;
+        aCodeID = -1;
+        aCodeRate = -1;
+        aDigit = -1;
+        channels = -1;
+        sampling = -1;
+    }
 
     static struct MovieInfo parseFromFile(const QFileInfo &fi, bool *ok = nullptr);
     QString durationStr() const
@@ -348,15 +340,12 @@ public:
 //        m_model = model;
 //        m_urls = urls;
         m_mutex = new QMutex;
-        m_itemMutex = new QMutex;
     };
     ~GetThumanbil()
     {
         m_stop = true;
         delete m_mutex;
         m_mutex = nullptr;
-        delete m_itemMutex;
-        m_itemMutex = nullptr;
     };
     //QList<PlayItemInfo> getInfoList() {return m_itemInfo;}
     void stop()
@@ -371,10 +360,10 @@ public:
     };
     void clearItem()
     {
-        m_itemMutex->lock();
+        m_mutex->lock();
         //m_itemInfo.clear();
         m_urls.clear();
-        m_itemMutex->unlock();
+        m_mutex->unlock();
     };
 
     void run()
@@ -384,11 +373,8 @@ public:
         m_mutex->unlock();
         foreach (QUrl url, urls) {
             QFileInfo info(url.path());
-            m_itemMutex->lock();
             //m_itemInfo.append();
             emit updateItem(m_model->calculatePlayInfo(url, info, false));
-            m_itemMutex->unlock();
-            m_isFinished = true;
             if (m_stop)
                 break;
         }
@@ -401,8 +387,6 @@ private:
     QList<QUrl> m_urls;
     //QList<PlayItemInfo> m_itemInfo;
     QMutex *m_mutex;
-    QMutex *m_itemMutex;
-    bool m_isFinished {true};
     bool m_stop {false};
 };
 
