@@ -1,36 +1,8 @@
-/*
- * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
- *
- * Author:     zhuyuliang <zhuyuliang@uniontech.com>
- *
- * Maintainer: xiepengfei <xiepengfei@uniontech.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
- * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
- * NON-INFRINGEMENT.  See the GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
- *
- * In addition, as a special exception, the copyright holders give
- * permission to link the code of portions of this program with the
- * OpenSSL library under certain conditions as described in each
- * individual source file, and distribute linked combinations
- * including the two.
- * You must obey the GNU General Public License in all respects
- * for all of the code used other than OpenSSL.  If you modify
- * file(s) with this exception, you may extend this exception to your
- * version of the file(s), but you are not obligated to do so.  If you
- * do not wish to do so, delete this exception statement from your
- * version.  If you delete this exception statement from all source
- * files in the program, then also delete it here.
- */
+// Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include <locale.h>
 
 #include <QtWidgets>
@@ -149,7 +121,8 @@ int main(int argc, char *argv[])
     DWIDGET_INIT_RESOURCE();
 #endif
     QFileInfo fi("/dev/mwv206_0");
-    if (fi.exists() && !CompositingManager::isMpvExists()) {
+    QFileInfo jmfi("/dev/jmgpu");
+    if ((fi.exists() || jmfi.exists()) && !CompositingManager::isMpvExists()) {
         qputenv("QT_XCB_GL_INTEGRATION", "xcb_egl");
     }
     /**
@@ -186,8 +159,8 @@ int main(int argc, char *argv[])
     app->setOrganizationName("deepin");
     app->setApplicationName("deepin-movie");
     app->setApplicationVersion(DMR_VERSION);
-    app->setProductIcon(utils::LoadHiDPIPixmap(":/resources/icons/logo-big.svg"));
-    app->setWindowIcon(QIcon(":/resources/icons/logo-big.svg"));
+    app->setProductIcon(QIcon::fromTheme("deepin-movie"));
+    app->setWindowIcon(QIcon::fromTheme("deepin-movie"));
     QString acknowledgementLink = "https://www.deepin.org/acknowledgments/deepin-movie";
     app->setApplicationAcknowledgementPage(acknowledgementLink);
     app->setApplicationVersion(DApplication::buildVersion(VERSION));
