@@ -1,36 +1,8 @@
-/*
- * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
- *
- * Author:     fengli <fengli@uniontech.com>
- *
- * Maintainer: xiepengfei <xiepengfei@uniontech.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
- * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
- * NON-INFRINGEMENT.  See the GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
- *
- * In addition, as a special exception, the copyright holders give
- * permission to link the code of portions of this program with the
- * OpenSSL library under certain conditions as described in each
- * individual source file, and distribute linked combinations
- * including the two.
- * You must obey the GNU General Public License in all respects
- * for all of the code used other than OpenSSL.  If you modify
- * file(s) with this exception, you may extend this exception to your
- * version of the file(s), but you are not obligated to do so.  If you
- * do not wish to do so, delete this exception statement from your
- * version.  If you delete this exception statement from all source
- * files in the program, then also delete it here.
- */
+// Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "config.h"
 
 #include "platform_toolbox_proxy.h"
@@ -607,21 +579,11 @@ public:
         QDBusReply<QString> reply = m_pWMDBus->call("CurrentWM");
         m_bIsWM = reply.value().contains("deepin wm");
         connect(m_pWMDBus, SIGNAL(WMChanged(QString)), this, SLOT(slotWMChanged(QString)));
-
-        auto *l = new QVBoxLayout;
-        l->setContentsMargins(0, 0, 0, 0);
-
-        _thumb = new DFrame(this);
         if (m_bIsWM) {
-            DStyle::setFrameRadius(_thumb, 8);
+            DStyle::setFrameRadius(this, 8);
         } else {
-            DStyle::setFrameRadius(_thumb, 0);
+            DStyle::setFrameRadius(this, 0);
         }
-
-        //_thumb->setFixedSize(ThumbnailWorker::thumbSize());
-        l->addWidget(_thumb/*,Qt::AlignTop*/);
-        setLayout(l);
-//        winId(); // force backed window to be created
         m_shadow_effect = new QGraphicsDropShadowEffect(this);
     }
 
@@ -655,12 +617,8 @@ public:
         QImage image;
         QPalette palette;
         image = rounded.toImage();
-        palette.setBrush(_thumb->backgroundRole(),
-                         QBrush(image.scaled(// 缩放背景图.
-                                    QSize(_thumb->width(), _thumb->height()),
-                                    Qt::IgnoreAspectRatio,
-                                    Qt::SmoothTransformation)));
-        _thumb->setPalette(palette);
+        m_thumbImg = image;
+        update();
     }
 
     void updateWithPreview(const QPoint &pos)
@@ -674,10 +632,10 @@ public slots:
     {
         if (msg.contains("deepin metacity")) {
             m_bIsWM = false;
-            DStyle::setFrameRadius(_thumb, 0);
+            DStyle::setFrameRadius(this, 0);
         } else {
             m_bIsWM = true;
-            DStyle::setFrameRadius(_thumb, 8);
+            DStyle::setFrameRadius(this, 8);
         }
     }
 
@@ -690,14 +648,20 @@ protected:
         m_shadow_effect->setColor(Qt::gray);
         m_shadow_effect->setBlurRadius(8);
         setGraphicsEffect(m_shadow_effect);
+        QPainter painter(this);
+        QPainterPath path;
+        QRect rt = rect().marginsRemoved(QMargins(1, 1, 1, 1));
         if (!m_bIsWM)
         {
-            QPainter painter(this);
-            QPainterPath path;
             path.addRect(rect());
             painter.fillPath(path, QColor(230, 230, 230));
+        } else {
+            path.addRoundRect(rt, 20, 20);
+            painter.setRenderHints(QPainter::Antialiasing, true);
         }
-
+        painter.setClipPath(path);
+        if(!m_thumbImg.isNull())
+            painter.drawImage(rt, m_thumbImg, QRect(0, 0, m_thumbImg.width(), m_thumbImg.height()));
         QWidget::paintEvent(e);
     }
     void leaveEvent(QEvent *e) override
@@ -717,17 +681,16 @@ private:
         pixmap.setDevicePixelRatio(dpr);
         pixmap = pixmap.scaled(size * dpr, Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation);
         pixmap.setDevicePixelRatio(dpr);
-        _thumb->setFixedSize(size);
         int offect = 2;
         if (!m_bIsWM) {
             offect = 0;
         }
-        this->setFixedWidth(_thumb->width() + offect);
-        this->setFixedHeight(_thumb->height() + offect);
+        this->setFixedWidth(size.width() + offect);
+        this->setFixedHeight(size.height() + offect);
     }
 
 private:
-    DFrame *_thumb {nullptr};
+    QImage m_thumbImg;
     int m_thumbnailFixed = 106;
     QGraphicsDropShadowEffect *m_shadow_effect{nullptr};
     QDBusInterface *m_pWMDBus{nullptr};
@@ -863,6 +826,8 @@ Platform_ToolboxProxy::Platform_ToolboxProxy(QWidget *mainWindow, PlayerEngine *
     m_pPreviewer = new Platform_ThumbnailPreview;
     m_pPreviewTime = new Platform_SliderTime;
     m_pPreviewTime->hide();
+    m_mircastWidget = new MircastWidget(mainWindow, proxy);
+    m_mircastWidget->hide();
     setup();
     slotThemeTypeChanged();
 
@@ -870,6 +835,8 @@ Platform_ToolboxProxy::Platform_ToolboxProxy(QWidget *mainWindow, PlayerEngine *
             this, &Platform_ToolboxProxy::updatePlayState);
     connect(DApplicationHelper::instance(), &DApplicationHelper::themeTypeChanged,
             this, &Platform_ToolboxProxy::updateplaylisticon);
+    connect(m_mircastWidget, &MircastWidget::updatePlayStatus, this, &Platform_ToolboxProxy::updatePlayState);
+    connect(m_mircastWidget, &MircastWidget::updateTime, this, &Platform_ToolboxProxy::updateMircastTime, Qt::QueuedConnection);
 }
 void Platform_ToolboxProxy::finishLoadSlot(QSize size)
 {
@@ -910,6 +877,12 @@ void Platform_ToolboxProxy::updateplaylisticon()
     } else {
         m_pListBtn->setIcon(QIcon::fromTheme("dcc_episodes"));
     }
+
+    if (m_pMircastBtn->isChecked() && DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
+        m_pMircastBtn->setIcon(QIcon(":/icons/deepin/builtin/light/checked/mircast_chenked.svg"));
+    } else {
+        m_pMircastBtn->setIcon(QIcon::fromTheme("dcc_mircast"));
+    }
 }
 
 void Platform_ToolboxProxy::setup()
@@ -1142,6 +1115,23 @@ void Platform_ToolboxProxy::setup()
     _right->addWidget(m_pVolBtn);
     _right->addSpacing(10);
 
+    m_pMircastBtn = new ToolButton(m_pBotToolWgt);
+    m_pMircastBtn->setIcon(QIcon::fromTheme("dcc_mircast", QIcon(":/resources/icons/mircast/mircast.svg")));
+    m_pMircastBtn->setIconSize(QSize(24, 24));
+    m_pMircastBtn->installEventFilter(this);
+    m_pMircastBtn->setCheckable(true);
+    m_pMircastBtn->setFixedSize(50, 50);
+    m_pMircastBtn->setFocusPolicy(Qt::TabFocus);
+    m_pMircastBtn->initToolTip();
+    m_pMircastBtn->setObjectName(MIRVAST_BUTTON);
+    m_pMircastBtn->setAccessibleName(MIRVAST_BUTTON);
+    connect(m_pMircastBtn, SIGNAL(clicked()), signalMapper, SLOT(map()));
+    signalMapper->setMapping(m_pMircastBtn, "mircast");
+    connect(m_mircastWidget, &MircastWidget::mircastState, this, &Platform_ToolboxProxy::slotUpdateMircast);
+
+    _right->addWidget(m_pMircastBtn);
+    _right->addSpacing(10);
+
     m_pListBtn = new ToolButton(m_pBotToolWgt);
     m_pListBtn->setIcon(QIcon::fromTheme("dcc_episodes"));
     m_pListBtn->setIconSize(QSize(36, 36));
@@ -1164,15 +1154,15 @@ void Platform_ToolboxProxy::setup()
     //lmh0910wayland下用这一套tooltip
     Platform_TooltipHandler *th = new Platform_TooltipHandler(this);
     QWidget *btns[] = {
-        m_pPlayBtn, m_pPrevBtn, m_pNextBtn, m_pFullScreenBtn, m_pListBtn
+        m_pPlayBtn, m_pPrevBtn, m_pNextBtn, m_pFullScreenBtn, m_pMircastBtn, m_pListBtn
     };
     QString hints[] = {
         tr("Play/Pause"), tr("Previous"), tr("Next"),
-        tr("Fullscreen"), tr("Playlist")
+        tr("Fullscreen"), tr("Miracast"), tr("Playlist")
     };
     QString attrs[] = {
         tr("play"), tr("prev"), tr("next"),
-        tr("fs"), tr("list")
+        tr("fs"), "mir", tr("list")
     };
 
     for (unsigned int i = 0; i < sizeof(btns) / sizeof(btns[0]); i++) {
@@ -1261,6 +1251,7 @@ void Platform_ToolboxProxy::initMember()
     m_pProgBar = nullptr;
     m_pPreviewer = nullptr;
     m_pPreviewTime = nullptr;
+    m_mircastWidget = nullptr;
 
     m_pPlayBtn = nullptr;
     m_pPrevBtn = nullptr;
@@ -1281,6 +1272,7 @@ void Platform_ToolboxProxy::initMember()
     m_pPaClose = nullptr;
 
     m_nClickTime = 0;
+    m_processAdd = 0.0;
 
     m_bMouseFlag = false;
     m_bMousePree = false;
@@ -1540,7 +1532,10 @@ void Platform_ToolboxProxy::slotSliderPressed()
 void Platform_ToolboxProxy::slotSliderReleased()
 {
     m_bMousePree = false;
-    m_pEngine->seekAbsolute(m_pProgBar->slider()->sliderPosition());
+    if (m_mircastWidget->getMircastState() == MircastWidget::Screening)
+        m_mircastWidget->slotSeekMircast(m_pProgBar->slider()->sliderPosition());
+    else
+        m_pEngine->seekAbsolute(m_pProgBar->slider()->sliderPosition());
 }
 
 void Platform_ToolboxProxy::slotBaseMuteChanged(QString sk, const QVariant &/*val*/)
@@ -1575,10 +1570,68 @@ void Platform_ToolboxProxy::slotFileLoaded()
     m_pProgBar->slider()->setRange(0, static_cast<int>(m_pEngine->duration()));
     m_pProgBar_Widget->setCurrentIndex(1);
     update();
+    //正在投屏时如果当前播放为音频直接播放下一首。
+    if(m_pEngine->currFileIsAudio()&&m_mircastWidget->getMircastState() != MircastWidget::Idel) {
+        //如果全是音频文件则退出投屏
+        bool isAllAudio = true;
+        QString sNextVideoName;
+        int nNextIndex = -1;
+        QList<PlayItemInfo> lstItemInfo = m_pEngine->getplaylist()->items();
+        for(int i = 0; i < lstItemInfo.count(); i++) {
+            PlayItemInfo iteminfo = lstItemInfo.at(i);
+            if(iteminfo.mi.vCodecID != -1) {
+                isAllAudio = false;
+                if(sNextVideoName.isNull()) {
+                    sNextVideoName = iteminfo.mi.filePath;
+                    nNextIndex = i;
+                    break;
+                }
+            }
+        }
+        if(isAllAudio) {
+            m_pMainWindow->slotExitMircast();
+            return;
+        }
+        QString sCurPath = m_pEngine->getplaylist()->currentInfo().mi.filePath;
+        int nIndex = -1;
+        for(int i = 0; i < lstItemInfo.count(); i++) {
+            PlayItemInfo iteminfo = lstItemInfo.at(i);
+            if(iteminfo.mi.filePath == sCurPath) {
+                nIndex = i;
+                break;
+            }
+        }
+        if(nIndex == -1) return;
+        if(nIndex < nNextIndex && !sNextVideoName.isNull()) {
+            m_pMainWindow->play({sNextVideoName});
+        } else{
+            bool isNext = true;
+            for(int i = nIndex; i < lstItemInfo.count(); i++) {
+                PlayItemInfo iteminfo = lstItemInfo.at(i);
+                if(iteminfo.mi.vCodecID != -1) {
+                    isNext = false;
+                    m_pMainWindow->play({iteminfo.mi.filePath});
+                    break;
+                }
+            }
+            if(m_pEngine->getplaylist()->playMode() == PlaylistModel::OrderPlay) {
+                if(isNext)
+                    m_pMainWindow->slotExitMircast();
+                return;
+            }
+            if(isNext && !sNextVideoName.isNull()){
+                m_pMainWindow->play({sNextVideoName});
+            }
+        }
+        return;
+    }
+    m_mircastWidget->playNext();
 }
 
 void Platform_ToolboxProxy::slotElapsedChanged()
 {
+    if(m_mircastWidget->getMircastState() != MircastWidget::Idel)
+        return;
     quint64 url = static_cast<quint64>(-1);
     if (m_pEngine->playlist().current() != -1) {
         url = static_cast<quint64>(m_pEngine->duration());
@@ -1698,6 +1751,25 @@ void Platform_ToolboxProxy::setBtnFocusSign(bool sign)
 {
     m_bSetListBtnFocus = sign;
 }
+
+bool Platform_ToolboxProxy::isInMircastWidget(const QPoint &p)
+{
+    if (!m_mircastWidget->isVisible())
+        return false;
+    return m_mircastWidget->geometry().contains(p);
+}
+
+void Platform_ToolboxProxy::updateMircastWidget(QPoint p)
+{
+    m_mircastWidget->move(p.x() - m_mircastWidget->width(), p.y() - m_mircastWidget->height() - 10);
+}
+
+void Platform_ToolboxProxy::hideMircastWidget()
+{
+    m_mircastWidget->hide();
+    m_pMircastBtn->setChecked(false);
+    updateplaylisticon();
+}
 /**
  * @brief volumeUp 鼠标滚轮增加音量
  */
@@ -1867,6 +1939,9 @@ void Platform_ToolboxProxy::updateButtonStates()
 
     if(m_pEngine->state() != PlayerEngine::CoreState::Idle) {
         bRawFormat = m_pEngine->getplaylist()->currentInfo().mi.isRawFormat();
+        m_pMircastBtn->setEnabled(!m_pEngine->currFileIsAudio());
+        if(m_pEngine->currFileIsAudio())
+            m_mircastWidget->setVisible(false);
         if(bRawFormat && !m_pEngine->currFileIsAudio()){                                             // 如果正在播放的视频是裸流不支持音量调节和进度调节
             m_pProgBar->setEnabled(false);
             m_pProgBar->setEnableIndication(false);
@@ -1943,9 +2018,27 @@ void Platform_ToolboxProxy::updateFullState()
     }
 }
 
+void Platform_ToolboxProxy::slotUpdateMircast(int state, QString msg)
+{
+    emit sigMircastState(state, msg);
+    if (state == 0) {
+        m_pVolBtn->setButtonEnable(false);
+        m_pFullScreenBtn->setEnabled(false);
+    } else {
+        bool bRawFormat = m_pEngine->getplaylist()->currentInfo().mi.isRawFormat();
+        if(bRawFormat && !m_pEngine->currFileIsAudio()) {
+            m_pVolBtn->setButtonEnable(false);
+        } else {
+            m_pVolBtn->setButtonEnable(true);
+        }
+        m_pFullScreenBtn->setEnabled(true);
+    }
+}
+
 void Platform_ToolboxProxy::updatePlayState()
 {
-    if (m_pEngine->state() == PlayerEngine::CoreState::Playing) {
+    if (((m_mircastWidget->getMircastState() != MircastWidget::Idel) && (m_mircastWidget->getMircastPlayState() == MircastWidget::Play))
+            || m_pEngine->state() == PlayerEngine::CoreState::Playing) {
         if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
             DPalette pa;
             pa = m_pPalyBox->palette();
@@ -1969,6 +2062,10 @@ void Platform_ToolboxProxy::updatePlayState()
             pa.setColor(DPalette::Dark, QColor(255, 255, 255, 255));
             m_pListBtn->setPalette(pa);
 
+            pa = m_pMircastBtn->palette();
+            pa.setColor(DPalette::Light, QColor(255, 255, 255, 255));
+            pa.setColor(DPalette::Dark, QColor(255, 255, 255, 255));
+            m_pMircastBtn->setPalette(pa);
         } else {
             DPalette pa;
             pa = m_pPalyBox->palette();
@@ -1991,6 +2088,11 @@ void Platform_ToolboxProxy::updatePlayState()
             pa.setColor(DPalette::Light, QColor(0, 0, 0, 255));
             pa.setColor(DPalette::Dark, QColor(0, 0, 0, 255));
             m_pListBtn->setPalette(pa);
+
+            pa = m_pMircastBtn->palette();
+            pa.setColor(DPalette::Light, QColor(0, 0, 0, 255));
+            pa.setColor(DPalette::Dark, QColor(0, 0, 0, 255));
+            m_pMircastBtn->setPalette(pa);
         }
         m_pPlayBtn->setIcon(QIcon::fromTheme("dcc_suspend", QIcon(":/icons/deepin/builtin/light/normal/suspend_normal.svg")));
         //lmh0910wayland下用这一套tooltip
@@ -2020,6 +2122,10 @@ void Platform_ToolboxProxy::updatePlayState()
             pa.setColor(DPalette::Dark, QColor(255, 255, 255, 255));
             m_pListBtn->setPalette(pa);
 
+            pa = m_pMircastBtn->palette();
+            pa.setColor(DPalette::Light, QColor(255, 255, 255, 255));
+            pa.setColor(DPalette::Dark, QColor(255, 255, 255, 255));
+            m_pMircastBtn->setPalette(pa);
         } else {
             DPalette pa;
             pa = m_pPalyBox->palette();
@@ -2043,6 +2149,11 @@ void Platform_ToolboxProxy::updatePlayState()
             pa.setColor(DPalette::Dark, QColor(0, 0, 0, 255));
             m_pListBtn->setPalette(pa);
 
+            pa = m_pMircastBtn->palette();
+            pa.setColor(DPalette::Light, QColor(0, 0, 0, 255));
+            pa.setColor(DPalette::Dark, QColor(0, 0, 0, 255));
+            m_pMircastBtn->setPalette(pa);
+
         }
         //lmh0910wayland下用这一套tooltip
         m_pPlayBtn->setToolTip(tr("Play"));
@@ -2133,6 +2244,14 @@ void Platform_ToolboxProxy::buttonClicked(QString id)
         m_nClickTime = QDateTime::currentMSecsSinceEpoch();
         m_pMainWindow->requestAction(ActionFactory::ActionKind::TogglePlaylist);
         m_pListBtn->hideToolTip();
+    } else if (id == "mircast") {
+        m_mircastWidget->togglePopup();
+        m_pMircastBtn->hideToolTip();
+        m_pMircastBtn->setChecked(m_mircastWidget->isVisible());
+        if (m_pMircastBtn->isChecked())
+            m_pMircastBtn->setIcon(QIcon(":/icons/deepin/builtin/light/checked/mircast_chenked.svg"));
+        else
+            m_pMircastBtn->setIcon(QIcon::fromTheme("dcc_mircast"));
     }
 }
 
@@ -2143,7 +2262,7 @@ void Platform_ToolboxProxy::buttonEnter()
     ToolButton *btn = qobject_cast<ToolButton *>(sender());
     QString id = btn->property("TipId").toString();
 
-    if (id == tr("sub") || id == tr("fs") || id == tr("list")) {
+    if (id == tr("sub") || id == tr("fs") || id == tr("list") || id == "mir") {
         updateToolTipTheme(btn);
         btn->showToolTip();
     }
@@ -2156,7 +2275,7 @@ void Platform_ToolboxProxy::buttonLeave()
     ToolButton *btn = qobject_cast<ToolButton *>(sender());
     QString id = btn->property("TipId").toString();
 
-    if (id == tr("sub") || id == tr("fs") || id == tr("list")) {
+    if (id == tr("sub") || id == tr("fs") || id == tr("list") || id == "mir") {
         btn->hideToolTip();
     }
 }
@@ -2270,6 +2389,29 @@ void Platform_ToolboxProxy::updateTimeLabel()
     }
 }
 
+void Platform_ToolboxProxy::updateMircastTime(int time)
+{
+    if (m_pProgBar_Widget->currentIndex() == 1) {              //进度条模式
+
+        if (!m_pProgBar->signalsBlocked()) {
+            m_pProgBar->blockSignals(true);
+        }
+
+        m_pProgBar->slider()->setSliderPosition(time);
+        m_pProgBar->slider()->setValue(time);
+        m_pProgBar->blockSignals(false);
+    } else {
+        m_pViewProgBar->setIsBlockSignals(true);
+        m_pViewProgBar->setValue(time);
+        m_pViewProgBar->setIsBlockSignals(false);
+    }
+    quint64 url = static_cast<quint64>(-1);
+    if (m_pEngine->playlist().current() != -1) {
+        url = static_cast<quint64>(m_pEngine->duration());
+    }
+    updateTimeInfo(url, time, m_pTimeLabel, m_pTimeLabelend, true);
+}
+
 void Platform_ToolboxProxy::updateToolTipTheme(ToolButton *btn)
 {
     if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
@@ -2372,7 +2514,21 @@ void Platform_ToolboxProxy::updateProgress(int nValue)
 
     if (m_pProgBar_Widget->currentIndex() == 1) {              //进度条模式
 
-        int nCurrPos = m_pProgBar->value() + nValue * nDuration / m_pProgBar->width();
+        float value = nValue * nDuration / m_pProgBar->width();
+        int nCurrPos;
+        if (value > 1 || value < -1) {
+            nCurrPos = m_pProgBar->value() + value;
+        } else {
+            if (m_processAdd < 1.0 && m_processAdd > -1.0) {
+                m_processAdd += (float)(nValue * nDuration) / m_pProgBar->width();
+                qInfo() << m_processAdd;
+                return;
+            }
+            else {
+                nCurrPos = m_pProgBar->value() + m_processAdd;
+                m_processAdd = .0;
+            }
+        }
         if (!m_pProgBar->signalsBlocked()) {
             m_pProgBar->blockSignals(true);
         }
