@@ -1,11 +1,35 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="fa">
+<TS version="2.0" language="fa">
 <context>
-    <name>Presenter</name>
+    <name>MircastShowWidget</name>
     <message>
-        <source>Volume: %1%</source>
-        <translation type="vanished">صدا %1%</translation>
+        <source>Projecting... 
+Please do not exit the Movie app during the process.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Display device</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Exit Miracast</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>MircastWidget</name>
+    <message>
+        <source>Project to</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Searching for devices...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No Miracast display devices were found. Please connect the device and your computer to the same WLAN network.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -490,18 +514,10 @@
         <source>Buffering...</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>No device found</source>
-        <translation type="vanished">دستگاهی پیدا نشد</translation>
-    </message>
     <message>
         <source>Open folder</source>
         <translation>باز کردن پوشه</translation>
     </message>
-    <message>
-        <source>All videos (%1)</source>
-        <translation type="vanished">همه ویدیو ها (1%)</translation>
-    </message>
     <message>
         <source>Stereo</source>
         <translation>استریو</translation>
@@ -546,10 +562,6 @@
         <source>Speed: %1x</source>
         <translation>سرعت: x1%</translation>
     </message>
-    <message>
-        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
-        <translation>زیرنویس (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
-    </message>
     <message>
         <source>View</source>
         <translation>نما</translation>
@@ -606,10 +618,6 @@
         <source>Reading DVD files...</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>All videos (%2 %1)</source>
-        <translation type="obsolete">همه ویدیو ها (1%) {2 %1)?}</translation>
-    </message>
     <message>
         <source>4K video may be stuck</source>
         <translation type="unfinished"></translation>
@@ -663,11 +671,16 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Audio (%1)</source>
+        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
+        <comment>All (*)</comment>
+        <translation type="unfinished">زیرنویس (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
+    </message>
+    <message>
+        <source>Connection failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Video (%1)</source>
+        <source>Miracast disconnected</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -675,19 +688,19 @@
     <name>dmr::MovieInfo</name>
     <message>
         <source>%1G</source>
-        <translation type="vanished">%1G</translation>
+        <translation>%1G</translation>
     </message>
     <message>
         <source>%1M</source>
-        <translation type="vanished">%1M</translation>
+        <translation>%1M</translation>
     </message>
     <message>
         <source>%1K</source>
-        <translation type="vanished">%1K</translation>
+        <translation>%1K</translation>
     </message>
     <message>
         <source>%1</source>
-        <translation type="vanished">%1</translation>
+        <translation>%1</translation>
     </message>
 </context>
 <context>
@@ -796,6 +809,275 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>dmr::Platform_MainWindow</name>
+    <message>
+        <source>Load successfully</source>
+        <translation type="unfinished">با موفقیت بازگذاری شد</translation>
+    </message>
+    <message>
+        <source>Load failed</source>
+        <translation type="unfinished">بارگذاری ناموفق بود</translation>
+    </message>
+    <message>
+        <source>Cannot play the disc</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Parse failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open folder</source>
+        <translation type="unfinished">باز کردن پوشه</translation>
+    </message>
+    <message>
+        <source>All (*)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Speed: %1x</source>
+        <translation type="unfinished">سرعت: x1%</translation>
+    </message>
+    <message>
+        <source>Stereo</source>
+        <translation type="unfinished">استریو</translation>
+    </message>
+    <message>
+        <source>Left channel</source>
+        <translation type="unfinished">کانال چپ</translation>
+    </message>
+    <message>
+        <source>Right channel</source>
+        <translation type="unfinished">کانال راست</translation>
+    </message>
+    <message>
+        <source>Track: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to adjust the subtitle</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Subtitle %1: %2s</source>
+        <translation type="unfinished">زیرنویس  %1:s2%</translation>
+    </message>
+    <message>
+        <source>delayed</source>
+        <translation type="unfinished">تعویق افتاده</translation>
+    </message>
+    <message>
+        <source>advanced</source>
+        <translation type="unfinished">پیشرفته</translation>
+    </message>
+    <message>
+        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
+        <comment>All (*)</comment>
+        <translation type="unfinished">زیرنویس (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
+    </message>
+    <message>
+        <source>View</source>
+        <translation type="unfinished">نما</translation>
+    </message>
+    <message>
+        <source>Film screenshot</source>
+        <translation type="unfinished">عکس گرفتن از فیلم</translation>
+    </message>
+    <message>
+        <source>Saved to</source>
+        <translation type="unfinished">ذخیره شده در</translation>
+    </message>
+    <message>
+        <source>The screenshot is saved</source>
+        <translation type="unfinished">اسکرین شات ذخیره شد</translation>
+    </message>
+    <message>
+        <source>Failed to save the screenshot</source>
+        <translation type="unfinished">اسکرین شات نتوانست ذخیره شود</translation>
+    </message>
+    <message>
+        <source>Taking the screenshots, please wait...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reading DVD files...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No matching online subtitles</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>4K video may be stuck</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">باشه</translation>
+    </message>
+    <message>
+        <source>Order play</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Shuffle play</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single play</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single loop</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>List loop</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Buffering...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mute</source>
+        <translation type="unfinished">بی صدا</translation>
+    </message>
+    <message>
+        <source>Volume: %1%</source>
+        <translation type="unfinished">صدا %1%</translation>
+    </message>
+    <message>
+        <source>Cannot open file or stream</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please insert a CD/DVD</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No video file found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please load the video first</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please exit smart dock</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The CD/DVD has been ejected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The action is not supported in this video</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid file: %1</source>
+        <translation type="unfinished">فابل نامعتبر : 1%</translation>
+    </message>
+    <message>
+        <source>Connection failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Miracast disconnected</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>dmr::Platform_PlayItemWidget</name>
+    <message>
+        <source>The file does not exist</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>dmr::Platform_PlaylistWidget</name>
+    <message>
+        <source>Playlist</source>
+        <translation type="unfinished">لیست پخش</translation>
+    </message>
+    <message>
+        <source>Empty</source>
+        <translation type="unfinished">خالی</translation>
+    </message>
+    <message>
+        <source>%1 videos</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>dmr::Platform_ToolboxProxy</name>
+    <message>
+        <source>Play/Pause</source>
+        <translation type="unfinished">پخش/مکث</translation>
+    </message>
+    <message>
+        <source>Previous</source>
+        <translation type="unfinished">پیشین</translation>
+    </message>
+    <message>
+        <source>Next</source>
+        <translation type="unfinished">بعدی</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="unfinished">تمام صفحه</translation>
+    </message>
+    <message>
+        <source>Playlist</source>
+        <translation type="unfinished">لیست پخش</translation>
+    </message>
+    <message>
+        <source>play</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>prev</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>next</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>fs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>list</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Exit fullscreen</source>
+        <translation type="unfinished">خروج از تمام صفحه</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation type="unfinished">مکث</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation type="unfinished">پخش</translation>
+    </message>
+    <message>
+        <source>sub</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Miracast</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>dmr::PlayItemWidget</name>
     <message>
@@ -871,10 +1153,6 @@
         <source>Next</source>
         <translation>بعدی</translation>
     </message>
-    <message>
-        <source>Subtitles</source>
-        <translation type="vanished">زیرنویس ها</translation>
-    </message>
     <message>
         <source>Playlist</source>
         <translation>لیست پخش</translation>
@@ -916,11 +1194,11 @@
         <translation>مکث</translation>
     </message>
     <message>
-        <source>Mute</source>
-        <translation type="obsolete">بی صدا</translation>
+        <source>sub</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>sub</source>
+        <source>Miracast</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
